import { useEffect, useState } from "react";
import { View,Image } from "@tarojs/components";
import Taro, { useDidShow, useReady } from "@tarojs/taro";
import style from "./index.module.less";
import NavBarNormal from "@/components/nav-bar-normal/index";
import LogoImage from '@/images/logo.png'
import PageCustom from "@/components/page-custom/index";
import { UserInfoResponse } from '@/xiaolanbenlib/api/auth'
import { onLogout, useIsLogin } from '@/xiaolanbenlib/hooks/data/useAuth'
import refreshUserId, { clearUserInfo, getOpenIdAsync } from '@/xiaolanbenlib/utils/auth'

import WelcomeTips from './components/welcome/index'
import { useAgentStore } from '@/store/agentStore'

export default function Index() {

  const [userInfo, setUserInfo] = useState<UserInfoResponse>()
  const isLogin = useIsLogin()

  const {fetchAgents} =  useAgentStore()

  function initUserInfo() {
    refreshUserId()
      .then((value) => {
        setUserInfo(value)
        getOpenIdAsync().then((openId) => {
          console.log('🚀 ~ getOpenIdAsync ~ value:', openId)
        })
        fetchAgents().then((value)=> {
          const agent = value[0]
          Taro.navigateTo({url: `/pages/profile/index?agentId=${agent.agentId}`})
        })
      })
      .catch((error) => {
        if (error.message === 'unauthorized' || error.code === 401) {
          Taro.showToast({
            title: '未登录',
            icon: 'none',
            duration: 2000,
          })
        }
      })
  }

  useEffect(() => {
    if (isLogin) {
      initUserInfo()
    }
    // Taro.navigateTo({url: '/pages/login/index'})
  }, [isLogin])
  

  const renderLogo = ()=> {
    return <View><Image className="w-68 h-24" src={LogoImage}></Image></View>
  }

  return (
    <PageCustom>
      <NavBarNormal leftColumn={renderLogo}></NavBarNormal>
      
      <WelcomeTips>
        <View className="flex items-center">
          <View>{userInfo?.logo && <Image className="w-24 h-24" src={userInfo?.logo}></Image>}</View>
          <View>{isLogin ? `已登录「${userInfo?.nickName}」` : '未登录'}</View>
        </View>      
      </WelcomeTips>
      
      </PageCustom>
  );
}
