import { create } from 'zustand'
import {
  bluebookAiAgent,
} from '@/xiaolanbenlib/api/index'
import request from '@/xiaolanbenlib/module/axios.js'

import { createAgent as _createAgent, deleteAgent as _deleteAgent } from "@/service/agent";
import { TAgentDetail, TAgent } from '@/types/agent'

export interface AgentStoreState {
  agents: TAgent[]
  agent: TAgentDetail | null
  fetchAgents: () => Promise<TAgent[]>
  fetchAgent: (agentId: string) => Promise<TAgentDetail | null>
  createAgent: (data: TAgentDetail) => Promise<TAgentDetail | null>
  // deleteAgent: (agentId: string) => Promise<void>
}




export const useAgentStore = create<AgentStoreState>((set, get) => ({
  agents: [],
  agent: null,
  fetchAgents: async () => {
    const response = await request.get<TAgent[]>(`${bluebookAiAgent}api/v1/my/agents`)
    if(response && response?.data?.length){
      set({ agents: response.data })
      return response.data
    }
    
    return []
  },
  fetchAgent: async (agentId: string) => {
    const response = await request.get<TAgentDetail>(`${bluebookAiAgent}api/v1/my/agent/${agentId}`)
    if(response.data){
      set({ agent: response.data})
      return response.data
    }
    return null
  },
  createAgent: async (data: TAgentDetail) => {
    const newAgent = await request.post(`${bluebookAiAgent}api/v1/my/agent`, data) as TAgentDetail
    if(newAgent){
      set((state) => {
        return {
          agents: [...state.agents, {
            "agentId": newAgent.agentId ?? '',
            "isDefault": newAgent.isDefault ?? false,
            "isEnt": newAgent.isEnt ?? false,
            "isNewEnt": newAgent.isNewEnt ?? false,
            "name": newAgent.name ?? ''
          }]
        }
      })
      return newAgent
    }
    return null
  },
  // deleteAgent: async (agentId: string)=> {
  //   const response = await _deleteAgent(agentId)
  //   if(response.status === 200){
  //     set((state) => {
  //       const agents = state.agents.filter((item: TAgentDetail) => item.agentId !== agentId)
  //       return {
  //         agents: [...agents]
  //       }
  //     })
  //   }
  // }
}))



